@@ -44,6 +44,8 @@ EC2API_ADMIN_USER=${EC2API_ADMIN_USER:-ec2api}
 
 EC2API_KEYSTONE_SIGNING_DIR=${EC2API_KEYSTONE_SIGNING_DIR:-/tmp/keystone-signing-ec2api}
 
+CACHE_BACKEND="oslo_cache.dict"
+
 # Support entry points installation of console scripts
 if [[ -d $EC2API_DIR/bin ]]; then
     EC2API_BIN_DIR=$EC2API_DIR/bin
@@ -149,12 +151,18 @@ function configure_ec2api_networking {
     if [[ -n "$ext_net" ]]; then
         iniset $EC2API_CONF_FILE DEFAULT external_network $ext_net
     fi
+    iniset $EC2API_CONF_FILE DEFAULT disable_ec2_classic True
+}
 
-    if [[ ,${ENABLED_SERVICES} =~ ,"q-" ]]; then
-        iniset $EC2API_CONF_FILE DEFAULT full_vpc_support True
-    else
-        iniset $EC2API_CONF_FILE DEFAULT full_vpc_support False
-    fi
+function create_x509_server_key() {
+  export CA_KEY="$EC2API_STATE_PATH/private/ca_key.pem"
+  export CA_CERT="$EC2API_STATE_PATH/cacert.pem"
+
+  mkdir -p "$EC2API_STATE_PATH/private/"
+
+  # generate root certificate
+  openssl genrsa -out "$CA_KEY" 2048
+  openssl req -x509 -new -key "$CA_KEY" -days 365 -out "$CA_CERT" -subj "/C=RU/ST=Moscow/L=Moscow/O=Progmatic/CN=ec2api-devstack"
 }
 
 # Entry points
@@ -188,12 +196,13 @@ function configure_ec2api {
     iniset $EC2API_CONF_FILE DEFAULT ec2api_listen_port "$EC2API_SERVICE_PORT"
     iniset $EC2API_CONF_FILE DEFAULT ec2_port "$EC2API_SERVICE_PORT"
 
+    local s3_port="$EC2API_S3_SERVICE_PORT"
+    local s3_protocol="http"
     if is_service_enabled swift3; then
-        iniset $EC2API_CONF_FILE DEFAULT s3_port "$S3_SERVICE_PORT"
-    else
-        iniset $EC2API_CONF_FILE DEFAULT s3_port "$EC2API_S3_SERVICE_PORT"
+        s3_port="$S3_SERVICE_PORT"
+        s3_protocol="$SWIFT_SERVICE_PROTOCOL"
     fi
-    iniset $EC2API_CONF_FILE DEFAULT s3_host "$SERVICE_HOST"
+    iniset $EC2API_CONF_FILE DEFAULT s3_url "$s3_protocol://$SERVICE_HOST:$s3_port"
 
     configure_ec2api_rpc_backend
 
@@ -221,6 +230,12 @@ function configure_ec2api {
         iniset $NOVA_CONF DEFAULT metadata_port 8789
         iniset $NOVA_CONF neutron service_metadata_proxy True
     fi
+    iniset $EC2API_CONF_FILE cache enabled True
+    iniset $EC2API_CONF_FILE cache backend "$CACHE_BACKEND"
+
+    if create_x509_server_key; then
+      iniset $EC2API_CONF_FILE DEFAULT x509_root_private_key "$CA_KEY"
+    fi
 }
 
 
