@@ -12,7 +12,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import base64
 import binascii
 import json
 import os
@@ -21,8 +20,13 @@ import tarfile
 import tempfile
 import time
 
-import boto.s3.connection
+import botocore.client
+import botocore.config
+import botocore.session
 from cinderclient import exceptions as cinder_exception
+from cryptography.hazmat import backends
+from cryptography.hazmat.primitives.asymmetric import padding
+from cryptography.hazmat.primitives import serialization
 import eventlet
 from glanceclient.common import exceptions as glance_exception
 from lxml import etree
@@ -30,6 +34,7 @@ from oslo_concurrency import processutils
 from oslo_config import cfg
 from oslo_log import log as logging
 from oslo_utils import timeutils
+import six
 
 from ec2api.api import common
 from ec2api.api import ec2utils
@@ -37,7 +42,7 @@ from ec2api.api import instance as instance_api
 from ec2api import clients
 from ec2api.db import api as db_api
 from ec2api import exception
-from ec2api.i18n import _, _LE, _LI, _LW
+from ec2api.i18n import _
 
 
 LOG = logging.getLogger(__name__)
@@ -46,20 +51,15 @@ s3_opts = [
     cfg.StrOpt('image_decryption_dir',
                default='/tmp',
                help='Parent directory for tempdir used for image decryption'),
-    cfg.StrOpt('s3_host',
-               default='$my_ip',
-               help='Hostname or IP for OpenStack to use when accessing '
-                    'the S3 api'),
-    cfg.IntOpt('s3_port',
-               default=3334,
-               help='Port used when accessing the S3 api'),
-    cfg.BoolOpt('s3_use_ssl',
-                default=False,
-                help='Whether to use SSL when talking to S3'),
-    cfg.BoolOpt('s3_affix_tenant',
-                default=False,
-                help='Whether to affix the tenant id to the access key '
-                     'when downloading from S3'),
+    cfg.StrOpt('s3_url',
+               default='http://$my_ip:3334',
+               help='URL to S3 server'),
+    # TODO(andrey-mp): this should be reworked with all region`s logic
+    cfg.StrOpt('s3_region',
+               default='RegionOne',
+               help='Region of S3 server'),
+    cfg.StrOpt('x509_root_private_key',
+               help='Path to ca private key file'),
 ]
 
 CONF = cfg.CONF
@@ -68,6 +68,8 @@ CONF.register_opts(s3_opts)
 rpcapi_opts = [
     cfg.StrOpt('cert_topic',
                default='cert',
+               deprecated_for_removal=True,
+               deprecated_reason='"nova_cert" service is removed',
                help='The topic cert nodes listen on'),
 ]
 
@@ -156,20 +158,19 @@ def create_image(context, instance_id, name=None, description=None,
             image['os_id'] = os_image_id
             db_api.update_item(context, image)
         except Exception:
-            LOG.exception(_LE('Failed to complete image %s creation'),
-                          image.id)
+            LOG.exception('Failed to complete image %s creation', image.id)
             try:
                 image['state'] = 'failed'
                 db_api.update_item(context, image)
             except Exception:
-                LOG.warning(_LW("Couldn't set 'failed' state for db image %s"),
+                LOG.warning("Couldn't set 'failed' state for db image %s",
                             image.id, exc_info=True)
 
         try:
             os_instance.start()
         except Exception:
-            LOG.warning(_LW('Failed to start instance %(i_id)s after '
-                            'completed creation of image %(image_id)s'),
+            LOG.warning('Failed to start instance %(i_id)s after '
+                        'completed creation of image %(image_id)s',
                         {'i_id': instance['id'],
                          'image_id': image['id']},
                         exc_info=True)
@@ -213,18 +214,17 @@ def register_image(context, name=None, image_location=None,
         raise exception.MissingParameter(msg)
 
     # TODO(ft): check parameters
-    properties = {}
-    metadata = {'properties': properties}
+    metadata = {}
     if name:
         # TODO(ft): check the name is unique (at least for EBS image case)
         metadata['name'] = name
     if image_location:
-        properties['image_location'] = image_location
+        metadata['image_location'] = image_location
         if 'name' not in metadata:
             # NOTE(ft): it's needed for backward compatibility
             metadata['name'] = image_location
     if root_device_name:
-        properties['root_device_name'] = root_device_name
+        metadata['root_device_name'] = root_device_name
     cinder = clients.cinder(context)
     if block_device_mapping:
         mappings = instance_api._parse_block_device_mapping(
@@ -246,27 +246,28 @@ def register_image(context, name=None, image_location=None,
                     bdm['volume_size'] = volume.size
             except cinder_exception.NotFound:
                 pass
-        properties['bdm_v2'] = True
-        properties['block_device_mapping'] = json.dumps(mappings)
+        metadata['bdm_v2'] = 'True'
+        metadata['block_device_mapping'] = json.dumps(mappings)
     if architecture is not None:
-        properties['architecture'] = architecture
+        metadata['architecture'] = architecture
     if kernel_id:
-        properties['kernel_id'] = ec2utils.get_os_image(context,
+        metadata['kernel_id'] = ec2utils.get_os_image(context,
                                                         kernel_id).id
     if ramdisk_id:
-        properties['ramdisk_id'] = ec2utils.get_os_image(context,
+        metadata['ramdisk_id'] = ec2utils.get_os_image(context,
                                                          ramdisk_id).id
 
     with common.OnCrashCleaner() as cleaner:
-        if 'image_location' in properties:
+        glance = clients.glance(context)
+        if 'image_location' in metadata:
             os_image = _s3_create(context, metadata)
         else:
-            metadata.update({'size': 0,
-                             'is_public': False})
-            # TODO(ft): set default values of image properties
-            glance = clients.glance(context)
+            metadata.update({'visibility': 'private',
+                             'container_format': 'bare',
+                             'disk_format': 'raw'})
             os_image = glance.images.create(**metadata)
-        cleaner.addCleanup(os_image.delete)
+            glance.images.upload(os_image.id, '', image_size=0)
+        cleaner.addCleanup(glance.images.delete, os_image.id)
         kind = _get_os_image_kind(os_image)
         image = db_api.add_item(context, kind, {'os_id': os_image.id,
                                                 'is_public': False,
@@ -366,9 +367,9 @@ class ImageDescriber(common.TaggableItemsDescriber):
     def get_os_items(self):
         os_images = list(clients.glance(self.context).images.list())
         self.ec2_created_os_images = {
-            os_image.properties['ec2_id']: os_image
+            os_image.ec2_id: os_image
             for os_image in os_images
-            if (os_image.properties.get('ec2_id') and
+            if (hasattr(os_image, 'ec2_id') and
                 self.context.project_id == os_image.owner)}
         return os_images
 
@@ -376,12 +377,12 @@ class ImageDescriber(common.TaggableItemsDescriber):
         if not image:
             kind = _get_os_image_kind(os_image)
             if self.context.project_id == os_image.owner:
-                if os_image.properties.get('ec2_id') in self.pending_images:
+                if getattr(os_image, 'ec2_id', None) in self.pending_images:
                     # NOTE(ft): the image is being creating, Glance had created
                     # image, but creating thread doesn't yet update db item
-                    image = self.pending_images[os_image.properties['ec2_id']]
+                    image = self.pending_images[os_image.ec2_id]
                     image['os_id'] = os_image.id
-                    image['is_public'] = os_image.is_public
+                    image['is_public'] = os_image.visibility == 'public'
                     db_api.update_item(self.context, image)
                 else:
                     image = ec2utils.get_db_item_by_os_id(
@@ -394,8 +395,8 @@ class ImageDescriber(common.TaggableItemsDescriber):
                 image = {'id': image_id,
                          'os_id': os_image.id}
         elif (self.context.project_id == os_image.owner and
-                image.get('is_public') != os_image.is_public):
-            image['is_public'] = os_image.is_public
+                image.get('is_public') != os_image.visibility == 'public'):
+            image['is_public'] = os_image.visibility == 'public'
             if image['id'] in self.local_images_os_ids:
                 db_api.update_item(self.context, image)
             else:
@@ -430,7 +431,7 @@ class ImageDescriber(common.TaggableItemsDescriber):
         os_image = self.ec2_created_os_images.get(item['id'])
         if os_image:
             item['os_id'] = os_image.id
-            item['is_public'] = os_image.is_public
+            item['is_public'] = os_image.visibility == 'public'
             db_api.update_item(self.context, item)
             image = self.format(item, os_image)
         else:
@@ -468,18 +469,18 @@ def describe_image_attribute(context, image_id, attribute):
 
     def _launch_permission_attribute(os_image, image, result):
         result['launchPermission'] = []
-        if os_image.is_public:
+        if os_image.visibility == 'public':
             result['launchPermission'].append({'group': 'all'})
 
     def _kernel_attribute(os_image, image, result):
-        kernel_id = os_image.properties.get('kernel_id')
+        kernel_id = getattr(os_image, 'kernel_id', None)
         if kernel_id:
             result['kernel'] = {
                 'value': ec2utils.os_id_to_ec2_id(context, 'aki', kernel_id)
             }
 
     def _ramdisk_attribute(os_image, image, result):
-        ramdisk_id = os_image.properties.get('ramdisk_id')
+        ramdisk_id = getattr(os_image, 'ramdisk_id', None)
         if ramdisk_id:
             result['ramdisk'] = {
                 'value': ec2utils.os_id_to_ec2_id(context, 'ari', ramdisk_id)
@@ -589,7 +590,9 @@ def modify_image_attribute(context, image_id, attribute=None,
                                                   reason=msg)
 
         _check_owner(context, os_image)
-        os_image.update(is_public=(operation_type == 'add'))
+        glance = clients.glance(context)
+        visibility = 'public' if operation_type == 'add' else 'private'
+        glance.images.update(os_image.id, visibility=visibility)
         return True
 
     if 'description' in attributes:
@@ -610,8 +613,8 @@ def reset_image_attribute(context, image_id, attribute):
 
     os_image = ec2utils.get_os_image(context, image_id)
     _check_owner(context, os_image)
-
-    os_image.update(is_public=False)
+    glance = clients.glance(context)
+    glance.images.update(os_image.id, visibility='private')
     return True
 
 
@@ -627,8 +630,8 @@ def _format_image(context, image, os_image, images_dict, ids_dict,
                  'imageOwnerId': os_image.owner,
                  'imageType': IMAGE_TYPES[
                                    ec2utils.get_ec2_id_kind(image['id'])],
-                 'isPublic': os_image.is_public,
-                 'architecture': os_image.properties.get('architecture'),
+                 'isPublic': os_image.visibility == 'public',
+                 'architecture': getattr(os_image, 'architecture', None),
                  'creationDate': os_image.created_at
                  }
     if 'description' in image:
@@ -638,23 +641,23 @@ def _format_image(context, image, os_image, images_dict, ids_dict,
     else:
         state = GLANCE_STATUS_TO_EC2.get(os_image.status, 'error')
     if state in ('available', 'pending'):
-        state = _s3_image_state_map.get(os_image.properties.get('image_state'),
+        state = _s3_image_state_map.get(getattr(os_image, 'image_state', None),
                                         state)
     ec2_image['imageState'] = state
 
-    kernel_id = os_image.properties.get('kernel_id')
+    kernel_id = getattr(os_image, 'kernel_id', None)
     if kernel_id:
         ec2_image['kernelId'] = ec2utils.os_id_to_ec2_id(
                 context, 'aki', kernel_id,
                 items_by_os_id=images_dict, ids_by_os_id=ids_dict)
-    ramdisk_id = os_image.properties.get('ramdisk_id')
+    ramdisk_id = getattr(os_image, 'ramdisk_id', None)
     if ramdisk_id:
         ec2_image['ramdiskId'] = ec2utils.os_id_to_ec2_id(
                 context, 'ari', ramdisk_id,
                 items_by_os_id=images_dict, ids_by_os_id=ids_dict)
 
     name = os_image.name
-    img_loc = os_image.properties.get('image_location')
+    img_loc = getattr(os_image, 'image_location', None)
     if img_loc:
         ec2_image['imageLocation'] = img_loc
     else:
@@ -783,7 +786,7 @@ def _get_os_image_kind(os_image):
 
 
 def _auto_create_image_extension(context, image, os_image):
-    image['is_public'] = os_image.is_public
+    image['is_public'] = os_image.visibility == 'public'
 
 
 ec2utils.register_auto_create_db_item_extension(
@@ -810,21 +813,23 @@ _s3_image_state_map = {'downloading': 'pending',
 
 def _s3_create(context, metadata):
     """Gets a manifest from s3 and makes an image."""
-    image_location = metadata['properties']['image_location'].lstrip('/')
+    image_location = metadata['image_location'].lstrip('/')
     bucket_name = image_location.split('/')[0]
     manifest_path = image_location[len(bucket_name) + 1:]
-    bucket = _s3_conn(context).get_bucket(bucket_name)
-    key = bucket.get_key(manifest_path)
-    manifest = key.get_contents_as_string()
+    s3_client = _s3_conn(context)
+    key = s3_client.get_object(Bucket=bucket_name, Key=manifest_path)
+    body = key['Body']
+    if isinstance(body, six.string_types):
+        manifest = body
+    else:
+        # TODO(andrey-mp): check big objects
+        manifest = body.read()
 
     (image_metadata, image_parts,
      encrypted_key, encrypted_iv) = _s3_parse_manifest(context, manifest)
-    properties = metadata['properties']
-    properties.update(image_metadata['properties'])
-    properties['image_state'] = 'pending'
     metadata.update(image_metadata)
-    metadata.update({'properties': properties,
-                     'is_public': False})
+    metadata.update({'image_state': 'pending',
+                     'visibility': 'private'})
 
     # TODO(bcwaldon): right now, this removes user-defined ids
     # We need to re-enable this.
@@ -834,7 +839,7 @@ def _s3_create(context, metadata):
     image = glance.images.create(**metadata)
 
     def _update_image_state(image_state):
-        image.update(properties={'image_state': image_state})
+        glance.images.update(image.id, image_state=image_state)
 
     def delayed_create():
         """This handles the fetching and decrypting of the part files."""
@@ -848,7 +853,8 @@ def _s3_create(context, metadata):
             try:
                 parts = []
                 for part_name in image_parts:
-                    part = _s3_download_file(bucket, part_name, image_path)
+                    part = _s3_download_file(s3_client, bucket_name,
+                                             part_name, image_path)
                     parts.append(part)
 
                 # NOTE(vish): this may be suboptimal, should we use cat?
@@ -859,8 +865,8 @@ def _s3_create(context, metadata):
                             shutil.copyfileobj(part, combined)
 
             except Exception:
-                LOG.exception(_LE('Failed to download %(image_location)s '
-                                  'to %(image_path)s'), log_vars)
+                LOG.exception('Failed to download %(image_location)s '
+                              'to %(image_path)s', log_vars)
                 _update_image_state('failed_download')
                 return
 
@@ -870,8 +876,8 @@ def _s3_create(context, metadata):
                 _s3_decrypt_image(context, enc_filename, encrypted_key,
                                   encrypted_iv, dec_filename)
             except Exception:
-                LOG.exception(_LE('Failed to decrypt %(image_location)s '
-                                  'to %(image_path)s'), log_vars)
+                LOG.exception('Failed to decrypt %(image_location)s '
+                              'to %(image_path)s', log_vars)
                 _update_image_state('failed_decrypt')
                 return
 
@@ -879,18 +885,18 @@ def _s3_create(context, metadata):
             try:
                 unz_filename = _s3_untarzip_image(image_path, dec_filename)
             except Exception:
-                LOG.exception(_LE('Failed to untar %(image_location)s '
-                                  'to %(image_path)s'), log_vars)
+                LOG.exception('Failed to untar %(image_location)s '
+                              'to %(image_path)s', log_vars)
                 _update_image_state('failed_untar')
                 return
 
             _update_image_state('uploading')
             try:
                 with open(unz_filename) as image_file:
-                    image.update(data=image_file)
+                    glance.images.upload(image.id, image_file)
             except Exception:
-                LOG.exception(_LE('Failed to upload %(image_location)s '
-                                  'to %(image_path)s'), log_vars)
+                LOG.exception('Failed to upload %(image_location)s '
+                              'to %(image_path)s', log_vars)
                 _update_image_state('failed_upload')
                 return
 
@@ -898,10 +904,9 @@ def _s3_create(context, metadata):
 
             shutil.rmtree(image_path)
         except glance_exception.HTTPNotFound:
-            LOG.info(_LI('Image %swas deleted underneath us'), image.id)
+            LOG.info('Image %swas deleted underneath us', image.id)
         except Exception:
-            LOG.exception(_LE('Failed to complete image %s creation'),
-                          image.id)
+            LOG.exception('Failed to complete image %s creation', image.id)
 
     eventlet.spawn_n(delayed_create)
 
@@ -916,7 +921,7 @@ def _s3_parse_manifest(context, manifest):
     except Exception:
         arch = 'x86_64'
 
-    properties = {'architecture': arch}
+    metadata = {'architecture': arch}
 
     mappings = []
     try:
@@ -930,7 +935,7 @@ def _s3_parse_manifest(context, manifest):
         mappings = []
 
     if mappings:
-        properties['mappings'] = mappings
+        metadata['mappings'] = mappings
 
     def set_dependent_image_id(image_key):
         try:
@@ -942,7 +947,7 @@ def _s3_parse_manifest(context, manifest):
         if image_id == 'true':
             return True
         os_image = ec2utils.get_os_image(context, image_id)
-        properties[image_key] = os_image.id
+        metadata[image_key] = os_image.id
 
     image_format = 'ami'
     if set_dependent_image_id('kernel_id'):
@@ -950,9 +955,8 @@ def _s3_parse_manifest(context, manifest):
     if set_dependent_image_id('ramdisk_id'):
         image_format = 'ari'
 
-    metadata = {'disk_format': image_format,
-                'container_format': image_format,
-                'properties': properties}
+    metadata.update({'disk_format': image_format,
+                     'container_format': image_format})
     image_parts = [
            fn_element.text
            for fn_element in manifest.find('image').getiterator('filename')]
@@ -962,10 +966,17 @@ def _s3_parse_manifest(context, manifest):
     return metadata, image_parts, encrypted_key, encrypted_iv
 
 
-def _s3_download_file(bucket, filename, local_dir):
-    key = bucket.get_key(filename)
+def _s3_download_file(s3_client, bucket_name, filename, local_dir):
+    s3_object = s3_client.get_object(Bucket=bucket_name, Key=filename)
     local_filename = os.path.join(local_dir, os.path.basename(filename))
-    key.get_contents_to_filename(local_filename)
+    body = s3_object['Body']
+    with open(local_filename, 'w') as f:
+        if isinstance(body, six.string_types):
+            f.write(body)
+        else:
+            # TODO(andrey-mp): check big objects
+            f.write(body.read())
+        f.close()
     return local_filename
 
 
@@ -973,14 +984,13 @@ def _s3_decrypt_image(context, encrypted_filename, encrypted_key,
                       encrypted_iv, decrypted_filename):
     encrypted_key = binascii.a2b_hex(encrypted_key)
     encrypted_iv = binascii.a2b_hex(encrypted_iv)
-    cert_client = clients.nova_cert(context)
     try:
-        key = cert_client.decrypt_text(base64.b64encode(encrypted_key))
+        key = _decrypt_text(encrypted_key)
     except Exception as exc:
         msg = _('Failed to decrypt private key: %s') % exc
         raise exception.EC2Exception(msg)
     try:
-        iv = cert_client.decrypt_text(base64.b64encode(encrypted_iv))
+        iv = _decrypt_text(encrypted_iv)
     except Exception as exc:
         msg = _('Failed to decrypt initialization vector: %s') % exc
         raise exception.EC2Exception(msg)
@@ -1020,17 +1030,33 @@ def _s3_test_for_malicious_tarball(path, filename):
 
 
 def _s3_conn(context):
-    # NOTE(vish): access and secret keys for s3 server are not
-    #             checked in nova-objectstore
+    region = CONF.s3_region
     ec2_creds = clients.keystone(context).ec2.list(context.user_id)
-    access = ec2_creds[0].access
-    if CONF.s3_affix_tenant:
-        access = '%s:%s' % (access, context.project_id)
-    secret = ec2_creds[0].secret
-    calling = boto.s3.connection.OrdinaryCallingFormat()
-    return boto.s3.connection.S3Connection(aws_access_key_id=access,
-                                           aws_secret_access_key=secret,
-                                           is_secure=CONF.s3_use_ssl,
-                                           calling_format=calling,
-                                           port=CONF.s3_port,
-                                           host=CONF.s3_host)
+
+    # Here we a) disable user's default config to let ec2api works independetly
+    # of user's local settings;
+    # b) specify region to be used by botocore;
+    # c) do not change standard botocore keys to get these settings
+    # from environment
+    connection_data = {
+        'config_file': (None, 'AWS_CONFIG_FILE', None, None),
+        'region': ('region', 'AWS_DEFAULT_REGION', region, None),
+    }
+    session = botocore.session.get_session(connection_data)
+    return session.create_client(
+        's3', region_name=region, endpoint_url=CONF.s3_url,
+        aws_access_key_id=ec2_creds[0].access,
+        aws_secret_access_key=ec2_creds[0].secret,
+        config=botocore.config.Config(signature_version='s3v4'))
+
+
+def _decrypt_text(text):
+    private_key_file = CONF.x509_root_private_key
+    if not private_key_file:
+        msg = _("Path to ca private key isn't configured")
+        raise exception.EC2Exception(msg)
+    with open(private_key_file, 'rb') as f:
+        data = f.read()
+    priv_key = serialization.load_pem_private_key(
+        data, None, backends.default_backend())
+    return priv_key.decrypt(text, padding.PKCS1v15())
