@@ -33,7 +33,7 @@ from ec2api import clients
 from ec2api import context as ec2_context
 from ec2api.db import api as db_api
 from ec2api import exception
-from ec2api.i18n import _, _LE
+from ec2api.i18n import _
 
 LOG = logging.getLogger(__name__)
 
@@ -72,10 +72,7 @@ class Validator(common.Validator):
 
 
 def get_instance_engine():
-    if CONF.full_vpc_support:
-        return InstanceEngineNeutron()
-    else:
-        return InstanceEngineNova()
+    return InstanceEngineNeutron()
 
 
 def run_instances(context, image_id, min_count, max_count,
@@ -97,16 +94,15 @@ def run_instances(context, image_id, min_count, max_count,
                                                    'value': [client_token]}])
         if reservations['reservationSet']:
             if len(reservations['reservationSet']) > 1:
-                LOG.error(_LE('describe_instances has returned %s '
-                              'reservations, but 1 is expected.') %
+                LOG.error('describe_instances has returned %s '
+                          'reservations, but 1 is expected.',
                           len(reservations['reservationSet']))
-                LOG.error(_LE('Requested instances client token: %s') %
-                          client_token)
-                LOG.error(_LE('Result: %s') % reservations)
+                LOG.error('Requested instances client token: %s', client_token)
+                LOG.error('Result: %s', reservations)
             return reservations['reservationSet'][0]
 
     os_image, os_kernel_id, os_ramdisk_id = _parse_image_parameters(
-            context, image_id, kernel_id, ramdisk_id)
+        context, image_id, kernel_id, ramdisk_id)
 
     nova = clients.nova(context)
     os_flavor = _get_os_flavor(instance_type, nova)
@@ -176,10 +172,10 @@ def run_instances(context, image_id, min_count, max_count,
     ec2_reservations = describe_instances(context, instance_ids)
     reservation_count = len(ec2_reservations['reservationSet'])
     if reservation_count != 1:
-        LOG.error(_LE('describe_instances has returned %s reservations, '
-                      'but 1 is expected.') % reservation_count)
-        LOG.error(_LE('Requested instances IDs: %s') % instance_ids)
-        LOG.error(_LE('Result: %s') % ec2_reservations)
+        LOG.error('describe_instances has returned %s reservations, '
+                  'but 1 is expected.', reservation_count)
+        LOG.error('Requested instances IDs: %s', instance_ids)
+        LOG.error('Result: %s', ec2_reservations)
     return (ec2_reservations['reservationSet'][0]
             if reservation_count else None)
 
@@ -302,10 +298,10 @@ class InstanceDescriber(common.TaggableItemsDescriber):
 
     def format(self, instance, os_instance):
         formatted_instance = _format_instance(
-                self.context, instance, os_instance,
-                self.ec2_network_interfaces.get(instance['id']),
-                self.image_ids, self.volumes, self.os_volumes,
-                self.os_flavors, self.groups_name_to_id)
+            self.context, instance, os_instance,
+            self.ec2_network_interfaces.get(instance['id']),
+            self.image_ids, self.volumes, self.os_volumes,
+            self.os_flavors, self.groups_name_to_id)
 
         reservation_id = instance['reservation_id']
         if reservation_id in self.reservations:
@@ -354,8 +350,8 @@ class InstanceDescriber(common.TaggableItemsDescriber):
     def auto_update_db(self, instance, os_instance):
         if not instance:
             instance = ec2utils.get_db_item_by_os_id(
-                    self.context, 'i', os_instance.id,
-                    os_instance=os_instance)
+                self.context, 'i', os_instance.id,
+                os_instance=os_instance)
         return instance
 
     def get_name(self, os_item):
@@ -434,8 +430,8 @@ def describe_instances(context, instance_id=None, filter=None,
 
     reservation_describer = ReservationDescriber()
     formatted_reservations = reservation_describer.describe(
-            context, ids=instance_id, filter=filter,
-            max_results=max_results, next_token=next_token)
+        context, ids=instance_id, filter=filter,
+        max_results=max_results, next_token=next_token)
 
     result = {'reservationSet': formatted_reservations}
     if reservation_describer.next_token:
@@ -541,8 +537,8 @@ def describe_instance_attribute(context, instance_id, attribute):
 
     def _format_attr_root_device_name(result):
         result['rootDeviceName'] = {
-                'value': getattr(os_instance,
-                                 'OS-EXT-SRV-ATTR:root_device_name', None)}
+            'value': getattr(os_instance,
+                             'OS-EXT-SRV-ATTR:root_device_name', None)}
 
     def _format_attr_user_data(result):
         user_data = getattr(os_instance, 'OS-EXT-SRV-ATTR:user_data', None)
@@ -1003,7 +999,7 @@ def _build_block_device_mapping(context, block_device_mapping, os_image):
 
                 _populate_parsed_bdm_parameter(bdm, short_root_device_name)
             else:
-                image_bdm = {k: v for k, v in six.iteritems(image_bdm)
+                image_bdm = {k: v for k, v in image_bdm.items()
                              if v is not None}
                 image_bdm.update(bdm)
                 bdm = image_bdm
@@ -1034,7 +1030,7 @@ def _populate_parsed_bdm_parameter(bdm, short_root_device_name):
 
 def _format_group_set(context, os_security_groups, groups):
     if not os_security_groups:
-        return None
+        return []
     return [{'groupName': sg['name'],
              'groupId': groups[sg['name']]}
             for sg in os_security_groups
@@ -1091,7 +1087,7 @@ def _get_os_instances_by_instances(context, instances, exactly=False,
         _remove_instances(context, obsolete_instances)
         if exactly:
             raise exception.InvalidInstanceIDNotFound(
-                                id=obsolete_instances[0]['id'])
+                id=obsolete_instances[0]['id'])
 
     return os_instances
 
@@ -1160,8 +1156,9 @@ class InstanceEngineNeutron(object):
             network_interface, multiple_instances):
         # TODO(ft): support auto_assign_floating_ip
 
-        vpc_network_parameters = self.merge_network_interface_parameters(
-            security_group,
+        (security_group,
+         vpc_network_parameters) = self.merge_network_interface_parameters(
+            context, security_group,
             subnet_id, private_ip_address, security_group_id,
             network_interface)
 
@@ -1169,7 +1166,7 @@ class InstanceEngineNeutron(object):
                                                 multiple_instances)
 
         (vpc_id, network_data) = self.parse_network_interface_parameters(
-                context, vpc_network_parameters)
+            context, vpc_network_parameters)
         launch_context = {'vpc_id': vpc_id,
                           'network_data': network_data,
                           'security_groups': security_group}
@@ -1225,7 +1222,7 @@ class InstanceEngineNeutron(object):
         # call of DB here to get corresponding network interfaces, but doesn't
         # lead to decrease DB and OS throughtput in called describe operation.
         enis = network_interface_api.describe_network_interfaces(
-                context)['networkInterfaceSet']
+            context)['networkInterfaceSet']
         ec2_network_interfaces = collections.defaultdict(list)
         for eni in enis:
             if (eni['status'] == 'in-use' and
@@ -1236,39 +1233,39 @@ class InstanceEngineNeutron(object):
         return ec2_network_interfaces
 
     def merge_network_interface_parameters(self,
+                                           context,
                                            security_group_names,
                                            subnet_id,
                                            private_ip_address,
                                            security_group_ids,
                                            network_interfaces):
-        network_interfaces = network_interfaces or []
 
         if ((subnet_id or private_ip_address or security_group_ids or
-                security_group_names) and
-                (len(network_interfaces) > 1 or
-                 # NOTE(ft): the only case in AWS when simple subnet_id
-                 # and/or private_ip_address parameters are compatible with
-                 # network_interface parameter is default behavior change of
-                 # public IP association for passed subnet_id by specifying
-                 # the only element in network_interfaces:
-                 # {"device_index": 0,
-                 #  "associate_public_ip_address": <boolean>}
-                 # Both keys must be in the dict, and no other keys
-                 # are allowed
-                 # We should support such combination of parameters for
-                 # compatibility purposes, even if we ignore
-                 # associate_public_ip_address in all other code
-                 len(network_interfaces) == 1 and
-                 (len(network_interfaces[0]) != 2 or
-                     ('associate_public_ip_address' not in
-                      network_interfaces[0]) or
-                     network_interfaces[0].get('device_index') != 0))):
+                security_group_names) and network_interfaces):
             msg = _(' Network interfaces and an instance-level subnet ID or '
                     'private IP address or security groups may not be '
                     'specified on the same request')
             raise exception.InvalidParameterCombination(msg)
 
-        if subnet_id:
+        if network_interfaces:
+            if (CONF.disable_ec2_classic and
+                len(network_interfaces) == 1 and
+                # NOTE(tikitavi): the case in AWS CLI when security_group_ids
+                # and/or private_ip_address parameters are set with
+                # network_interface parameter having
+                # associate_public_ip_address setting
+                # private_ip_address and security_group_ids in that case
+                # go to network_interface parameter
+                'associate_public_ip_address' in network_interfaces[0] and
+                'device_index' in network_interfaces[0] and
+                network_interfaces[0]['device_index'] == 0 and
+                ('subnet_id' not in network_interfaces[0] or
+                 'network_interface_id' not in network_interfaces[0])):
+
+                subnet_id = self.get_default_subnet(context)['id']
+                network_interfaces[0]['subnet_id'] = subnet_id
+            return None, network_interfaces
+        elif subnet_id:
             if security_group_names:
                 msg = _('The parameter groupName cannot be used with '
                         'the parameter subnet')
@@ -1279,7 +1276,25 @@ class InstanceEngineNeutron(object):
                 param['private_ip_address'] = private_ip_address
             if security_group_ids:
                 param['security_group_id'] = security_group_ids
-            return [param]
+            return None, [param]
+        elif CONF.disable_ec2_classic:
+            subnet_id = self.get_default_subnet(context)['id']
+            param = {'device_index': 0,
+                     'subnet_id': subnet_id}
+            if security_group_ids or security_group_names:
+                security_group_id = security_group_ids or []
+                if security_group_names:
+                    security_groups = (
+                        security_group_api.describe_security_groups(
+                            context, group_name=security_group_names)
+                        ['securityGroupInfo'])
+                    security_group_id.extend(sg['groupId']
+                                             for sg in security_groups)
+
+                param['security_group_id'] = security_group_id
+            if private_ip_address:
+                param['private_ip_address'] = private_ip_address
+            return None, [param]
         elif private_ip_address:
             msg = _('Specifying an IP address is only valid for VPC instances '
                     'and thus requires a subnet in which to launch')
@@ -1288,8 +1303,18 @@ class InstanceEngineNeutron(object):
             msg = _('VPC security groups may not be used for a non-VPC launch')
             raise exception.InvalidParameterCombination(msg)
         else:
-            # NOTE(ft): only one of this variables is not empty
-            return network_interfaces
+            return security_group_names, []
+
+    def get_default_subnet(self, context):
+        default_vpc = ec2utils.get_default_vpc(context)
+        subnet = next(
+            (subnet for subnet in db_api.get_items(context, 'subnet')
+             if subnet['vpc_id'] == default_vpc['id']), None)
+        if not subnet:
+            raise exception.MissingInput(
+                _("No subnets found for the default VPC '%s'. "
+                  "Please specify a subnet.") % default_vpc['id'])
+        return subnet
 
     def check_network_interface_parameters(self, params, multiple_instances):
         # NOTE(ft): we ignore associate_public_ip_address
@@ -1369,7 +1394,7 @@ class InstanceEngineNeutron(object):
 
         if busy_network_interfaces:
             raise exception.InvalidNetworkInterfaceInUse(
-                    interface_ids=busy_network_interfaces)
+                interface_ids=busy_network_interfaces)
 
         if len(vpc_ids) > 1:
             msg = _('Network interface attachments may not cross '
@@ -1431,36 +1456,15 @@ class InstanceEngineNeutron(object):
                                    not n.get('name').startswith('subnet-')]
         if len(ec2_classic_os_networks) == 0:
             raise exception.Unsupported(
-                    reason=_('There are no available networks '
-                             'for EC2 Classic mode'))
+                reason=_('There are no available networks '
+                         'for EC2 Classic mode'))
         if len(ec2_classic_os_networks) > 1:
             raise exception.Unsupported(
-                    reason=_('There is more than one available network '
-                             'for EC2 Classic mode'))
+                reason=_('There is more than one available network '
+                         'for EC2 Classic mode'))
         return ec2_classic_os_networks[0]
 
 
-class InstanceEngineNova(object):
-
-    def get_vpc_and_build_launch_context(
-            self, context, security_group,
-            subnet_id, private_ip_address, security_group_id,
-            network_interface, multiple_instances):
-        # TODO(ft): check emptiness of vpc related parameters
-
-        return None, {'security_groups': security_group}
-
-    def get_launch_extra_parameters(self, context, cleaner, launch_context):
-        return {'security_groups': launch_context['security_groups']}
-
-    def post_launch_action(self, context, cleaner, launch_context,
-                           instance_id):
-        pass
-
-    def get_ec2_network_interfaces(self, context, instance_ids=None):
-        return {}
-
-
 instance_engine = get_instance_engine()
 
 
@@ -1679,7 +1683,7 @@ _NAME_TO_CODE = {
     inst_state_SUSPEND: inst_state_STOPPED_CODE,
     inst_state_RESCUE: inst_state_RUNNING_CODE,
 }
-_CODE_TO_NAMES = {code: [item[0] for item in six.iteritems(_NAME_TO_CODE)
+_CODE_TO_NAMES = {code: [item[0] for item in _NAME_TO_CODE.items()
                          if item[1] == code]
                   for code in set(six.itervalues(_NAME_TO_CODE))}
 
