@@ -22,11 +22,11 @@ from oslo_log import log as logging
 from oslo_utils import timeutils
 
 from ec2api.api import address as address_api
-from ec2api.api import clients
 from ec2api.api import common
 from ec2api.api import dhcp_options
 from ec2api.api import ec2utils
 from ec2api.api import security_group as security_group_api
+from ec2api import clients
 from ec2api.db import api as db_api
 from ec2api import exception
 from ec2api.i18n import _
@@ -87,6 +87,8 @@ def create_network_interface(context, subnet_id,
             fixed_ips.append({'ip_address': str(ip_address)})
     if not fixed_ips and not secondary_private_ip_address_count:
         secondary_private_ip_address_count = 1
+    if secondary_private_ip_address_count is None:
+        secondary_private_ip_address_count = 0
     if secondary_private_ip_address_count > 0:
         for _i in range(secondary_private_ip_address_count):
             fixed_ips.append({'subnet_id': os_subnet['id']})
@@ -116,8 +118,7 @@ def create_network_interface(context, subnet_id,
             os_port = neutron.create_port(os_port_body)['port']
         except (neutron_exception.IpAddressGenerationFailureClient,
                 neutron_exception.OverQuotaClient):
-            raise exception.NetworkInterfaceLimitExceeded(
-                        subnet_id=subnet_id)
+            raise exception.InsufficientFreeAddressesInSubnet()
         except (neutron_exception.IpAddressInUseClient,
                 neutron_exception.BadRequest) as ex:
             # NOTE(ft): AWS returns InvalidIPAddress.InUse for a primary IP
@@ -277,8 +278,7 @@ def assign_private_ip_addresses(context, network_interface_id,
         neutron.update_port(os_port['id'],
                             {'port': {'fixed_ips': fixed_ips}})
     except neutron_exception.IpAddressGenerationFailureClient:
-        raise exception.NetworkInterfaceLimitExceeded(
-                    subnet_id=subnet['id'])
+        raise exception.InsufficientFreeAddressesInSubnet()
     except neutron_exception.IpAddressInUseClient:
         msg = _('Some of %(addresses)s is assigned, but move is not '
                 'allowed.') % {'addresses': private_ip_address}
@@ -315,14 +315,49 @@ def unassign_private_ip_addresses(context, network_interface_id,
 
 
 def describe_network_interface_attribute(context, network_interface_id,
-                                         attribute):
+                                         attribute=None):
+    if attribute is None:
+        raise exception.InvalidParameterCombination(
+            _('No attributes specified.'))
     network_interface = ec2utils.get_db_item(context, network_interface_id)
-    # TODO(Alex): Implement attachments, groupSet
 
-    db_key = attribute if attribute == 'description' else 'source_dest_check'
-    default_value = '' if attribute == 'description' else True
-    return {'networkInterfaceId': network_interface['id'],
-            attribute: {'value': network_interface.get(db_key, default_value)}}
+    def _format_attr_description(result):
+        result['description'] = {
+            'value': network_interface.get('description', '')}
+
+    def _format_attr_source_dest_check(result):
+        result['sourceDestCheck'] = {
+            'value': network_interface.get('source_dest_check', True)}
+
+    def _format_attr_group_set(result):
+        ec2_network_interface = describe_network_interfaces(context,
+            network_interface_id=[network_interface_id]
+        )['networkInterfaceSet'][0]
+        result['groupSet'] = ec2_network_interface['groupSet']
+
+    def _format_attr_attachment(result):
+        ec2_network_interface = describe_network_interfaces(context,
+            network_interface_id=[network_interface_id]
+        )['networkInterfaceSet'][0]
+        if 'attachment' in ec2_network_interface:
+            result['attachment'] = ec2_network_interface['attachment']
+
+    attribute_formatter = {
+        'description': _format_attr_description,
+        'sourceDestCheck': _format_attr_source_dest_check,
+        'groupSet': _format_attr_group_set,
+        'attachment': _format_attr_attachment,
+    }
+
+    fn = attribute_formatter.get(attribute)
+    if fn is None:
+        raise exception.InvalidParameterValue(value=attribute,
+                                              parameter='attribute',
+                                              reason='Unknown attribute.')
+
+    result = {'networkInterfaceId': network_interface['id']}
+    fn(result)
+    return result
 
 
 def modify_network_interface_attribute(context, network_interface_id,
