@@ -23,9 +23,8 @@ from novaclient import api_versions as nova_api_versions
 from novaclient import client as novaclient
 from oslo_config import cfg
 from oslo_log import log as logging
-import oslo_messaging as messaging
 
-from ec2api.i18n import _, _LI, _LW
+from ec2api.i18n import _
 
 logger = logging.getLogger(__name__)
 
@@ -91,7 +90,10 @@ LEGACY_NOVA_API_VERSION = '2'
 # properties
 # Nova API's 2.10 microversion provides admin access to users keypairs,
 # which allows metadata service to expose openssh part of an instance key
-REQUIRED_NOVA_API_MICROVERSION = '2.10'
+# Nova API's 2.32 microversion allows 'tag' field of bdm v2, which may be
+# contained in image bdms, defined by users or autocreated with instance
+# snapshot
+REQUIRED_NOVA_API_MICROVERSION = '2.32'
 _nova_api_version = None
 
 
@@ -114,7 +116,7 @@ def neutron(context):
 
 
 def glance(context):
-    return glanceclient.Client('1', service_type='image',
+    return glanceclient.Client(version='2', service_type='image',
                                session=context.session)
 
 
@@ -134,11 +136,6 @@ def keystone(context):
                                  session=context.session)
 
 
-def nova_cert(context):
-    _cert_api = _rpcapi_CertAPI(context)
-    return _cert_api
-
-
 def _get_nova_api_version(context):
     client = novaclient.Client(REQUIRED_NOVA_API_VERSION,
                                session=context.session,
@@ -148,80 +145,37 @@ def _get_nova_api_version(context):
     current = client.versions.get_current()
     if not current:
         logger.warning(
-            _LW('Could not check Nova API version because no version '
-                'was found in Nova version list for url %(url)s of service '
-                'type "%(service_type)s". '
-                'Use v%(required_api_version)s Nova API.'),
+            'Could not check Nova API version because no version '
+            'was found in Nova version list for url %(url)s of service '
+            'type "%(service_type)s". '
+            'Use v%(required_api_version)s Nova API.',
             {'url': client.client.get_endpoint(),
              'service_type': CONF.nova_service_type,
              'required_api_version': REQUIRED_NOVA_API_MICROVERSION})
         return REQUIRED_NOVA_API_MICROVERSION
     if current.id != REQUIRED_NOVA_API_VERSION_ID:
         logger.warning(
-            _LW('Specified "%s" Nova service type does not support v2.1 API. '
-                'A lot of useful EC2 compliant instance properties '
-                'will be unavailable.'),
-            CONF.nova_service_type)
+            'Specified "%s" Nova service type does not support v2.1 API. '
+            'A lot of useful EC2 compliant instance properties '
+            'will be unavailable.', CONF.nova_service_type)
         return LEGACY_NOVA_API_VERSION
     if (nova_api_versions.APIVersion(current.version) < required):
         logger.warning(
-            _LW('Nova support v%(nova_api_version)s, '
-                'but v%(required_api_version)s is required. '
-                'A lot of useful EC2 compliant instance properties '
-                'will be unavailable.'),
+            'Nova support v%(nova_api_version)s, '
+            'but v%(required_api_version)s is required. '
+            'A lot of useful EC2 compliant instance properties '
+            'will be unavailable.',
             {'nova_api_version': current.version,
              'required_api_version': REQUIRED_NOVA_API_MICROVERSION})
         return current.version
-    logger.info(_LI('Provided Nova API version is  v%(nova_api_version)s, '
-                    'used one is v%(required_api_version)s'),
+    logger.info('Provided Nova API version is  v%(nova_api_version)s, '
+                'used one is v%(required_api_version)s',
                 {'nova_api_version': current.version,
                  'required_api_version': (
                         REQUIRED_NOVA_API_MICROVERSION)})
     return REQUIRED_NOVA_API_MICROVERSION
 
 
-class _rpcapi_CertAPI(object):
-    '''Client side of the cert rpc API.'''
-
-    def __init__(self, context):
-        super(_rpcapi_CertAPI, self).__init__()
-        target = messaging.Target(topic=CONF.cert_topic, version='2.0')
-        self.client = _rpc_get_client(target)
-        self.context = context
-
-    def decrypt_text(self, text):
-        cctxt = self.client.prepare()
-        return cctxt.call(self.context, 'decrypt_text',
-                          project_id=self.context.project_id,
-                          text=text)
-
-
-_rpc_TRANSPORT = None
-
-
-def _rpc_init(conf):
-    global _rpc_TRANSPORT
-    # NOTE(ft): set control_exchange parameter to use Nova cert topic
-    messaging.set_transport_defaults('nova')
-    _rpc_TRANSPORT = messaging.get_transport(conf)
-
-
-def _rpc_get_client(target):
-    if not _rpc_TRANSPORT:
-        _rpc_init(CONF)
-    assert _rpc_TRANSPORT is not None
-    serializer = _rpc_RequestContextSerializer()
-    return messaging.RPCClient(_rpc_TRANSPORT,
-                               target,
-                               serializer=serializer)
-
-
-class _rpc_RequestContextSerializer(messaging.NoOpSerializer):
-
-    def serialize_context(self, context):
-        return context.to_dict()
-
-
 _admin_session = None
 
 
