@@ -18,6 +18,7 @@ import time
 import botocore.exceptions
 from oslo_log import log
 from tempest.lib.common.utils import data_utils
+from tempest.lib import decorators
 
 from ec2api.tests.functional import base
 from ec2api.tests.functional import config
@@ -32,6 +33,13 @@ class TagsPagingTest(scenario_base.BaseScenarioTest):
     # NOTE(andrey-mp): limit for tags for one resource in amazon
     TAGS_COUNT = 10
 
+    @classmethod
+    @base.safe_setup
+    def setUpClass(cls):
+        super(TagsPagingTest, cls).setUpClass()
+        if 'amazon' in CONF.aws.ec2_url:
+            raise cls.skipException('Paging is broken in Amazon.')
+
     def _create_volume_and_tags(self):
         data = self.client.create_volume(
             Size=1, AvailabilityZone=CONF.aws.aws_zone)
@@ -49,6 +57,7 @@ class TagsPagingTest(scenario_base.BaseScenarioTest):
 
         return volume_id, keys
 
+    @decorators.idempotent_id('8df6e612-07cd-466d-99de-9f37954a6c9a')
     def test_simple_tags_paging_with_many_results(self):
         volume_id = self._create_volume_and_tags()[0]
 
@@ -58,6 +67,7 @@ class TagsPagingTest(scenario_base.BaseScenarioTest):
         self.assertNotEmpty(data['Tags'])
         self.assertEqual(self.TAGS_COUNT, len(data['Tags']))
 
+    @decorators.idempotent_id('683883d5-9a94-43f2-a1eb-d193db0e44e9')
     def test_simple_tags_paging_with_min_results(self):
         volume_id = self._create_volume_and_tags()[0]
 
@@ -68,6 +78,7 @@ class TagsPagingTest(scenario_base.BaseScenarioTest):
         self.assertIn('NextToken', data)
         self.assertNotEmpty(data['Tags'])
 
+    @decorators.idempotent_id('1db8cc5a-d0b3-4e5f-b411-d84cfa4f21e0')
     def test_tags_paging_second_page_only_with_token(self):
         volume_id = self._create_volume_and_tags()[0]
 
@@ -84,6 +95,7 @@ class TagsPagingTest(scenario_base.BaseScenarioTest):
         self.assertNotIn('NextToken', data)
         self.assertNotEmpty(data['Tags'])
 
+    @decorators.idempotent_id('a4d7b315-9616-4f9e-85b7-0f892e09a9a2')
     def test_tags_paging_with_const_filter(self):
         volume_id = self._create_volume_and_tags()[0]
 
@@ -100,6 +112,7 @@ class TagsPagingTest(scenario_base.BaseScenarioTest):
         self.assertNotIn('NextToken', data)
         self.assertNotEmpty(data['Tags'])
 
+    @decorators.idempotent_id('ad4b793a-8231-4d30-8c26-43736b7b71e4')
     def test_tags_paging_with_differenet_filters(self):
         volume_id = self._create_volume_and_tags()[0]
 
@@ -115,6 +128,7 @@ class TagsPagingTest(scenario_base.BaseScenarioTest):
         self.assertNotEmpty(data['Tags'])
         self.assertLessEqual(1, len(data['Tags']))
 
+    @decorators.idempotent_id('ec6d68bb-37f3-4c5c-b4c5-000d73fbc1bf')
     def test_tags_paging_with_tags_deletion(self):
         volume_id, keys = self._create_volume_and_tags()
 
@@ -130,6 +144,7 @@ class TagsPagingTest(scenario_base.BaseScenarioTest):
         self.assertNotIn('NextToken', data)
         self.assertEmpty(data['Tags'])
 
+    @decorators.idempotent_id('37eb0597-998f-4744-8462-d56e5599dcd8')
     def test_invalid_max_results(self):
         self.assertRaises('InvalidParameterValue',
             self.client.describe_tags, MaxResults=4)
@@ -147,6 +162,9 @@ class VolumesPagingTest(scenario_base.BaseScenarioTest):
     @base.safe_setup
     def setUpClass(cls):
         super(VolumesPagingTest, cls).setUpClass()
+        if 'amazon' in CONF.aws.ec2_url:
+            raise cls.skipException('Paging is broken in Amazon.')
+
         zone = CONF.aws.aws_zone
         cls.ids = list()
         for dummy in xrange(0, cls.VOLUMES_COUNT):
@@ -158,17 +176,20 @@ class VolumesPagingTest(scenario_base.BaseScenarioTest):
         for volume_id in cls.ids:
             cls.get_volume_waiter().wait_available(volume_id)
 
+    @decorators.idempotent_id('d44ea940-d9ae-42a4-b3ce-add296a1678c')
     def test_simple_volumes_paging_with_many_results(self):
         data = self.client.describe_volumes(MaxResults=500)
         self.assertNotIn('NextToken', data)
         self.assertNotEmpty(data['Volumes'])
         self.assertLessEqual(self.VOLUMES_COUNT, len(data['Volumes']))
 
+    @decorators.idempotent_id('9780c871-ee90-411c-b6ec-1e2f1785926b')
     def test_simple_volumes_paging_with_min_results(self):
         data = self.client.describe_volumes(MaxResults=5)
         self.assertIn('NextToken', data)
         self.assertNotEmpty(data['Volumes'])
 
+    @decorators.idempotent_id('692684c4-62bc-457a-899a-07cc5382c9ab')
     def test_volumes_paging_second_page(self):
         data = self.client.describe_volumes(MaxResults=5)
         self.assertIn('NextToken', data)
@@ -178,6 +199,7 @@ class VolumesPagingTest(scenario_base.BaseScenarioTest):
         self.assertNotIn('NextToken', data)
         self.assertNotEmpty(data['Volumes'])
 
+    @decorators.idempotent_id('83183fac-bb9b-4c36-8d23-84ed55c57015')
     def test_invalid_paging(self):
         self.assertRaises('InvalidParameterValue',
             self.client.describe_volumes, MaxResults=4)
@@ -186,6 +208,7 @@ class VolumesPagingTest(scenario_base.BaseScenarioTest):
             self.client.describe_volumes,
             MaxResults=5, VolumeIds=[self.ids[0]])
 
+    @decorators.idempotent_id('2a777d78-9f0b-4ab0-a841-73dbaafae0dd')
     def test_volumes_paging_with_filters(self):
         data = self.client.describe_volumes(MaxResults=5,
             Filters=[{'Name': 'volume-id', 'Values': [self.ids[0]]}])
@@ -216,6 +239,9 @@ class SnapshotPagingTest(scenario_base.BaseScenarioTest):
     @base.safe_setup
     def setUpClass(cls):
         super(SnapshotPagingTest, cls).setUpClass()
+        if 'amazon' in CONF.aws.ec2_url:
+            raise cls.skipException('Paging is broken in Amazon.')
+
         zone = CONF.aws.aws_zone
 
         data = cls.client.create_volume(Size=1, AvailabilityZone=zone)
@@ -245,6 +271,7 @@ class SnapshotPagingTest(scenario_base.BaseScenarioTest):
                                                      final_set=('completed'))
             cls.ids.append(snapshot_id)
 
+    @decorators.idempotent_id('f44729b1-42d7-4f18-b5e0-f8dc2a03e624')
     def test_simple_snapshots_paging_with_many_results(self):
         data = self.client.describe_snapshots(MaxResults=500,
                                               OwnerIds=['self'])
@@ -255,11 +282,13 @@ class SnapshotPagingTest(scenario_base.BaseScenarioTest):
                 count += 1
         self.assertEqual(self.SNAPSHOTS_COUNT, count)
 
+    @decorators.idempotent_id('3146c81d-84c0-4817-9318-328f92bece7f')
     def test_simple_snapshots_paging_with_min_results(self):
         data = self.client.describe_snapshots(MaxResults=5, OwnerIds=['self'])
         self.assertIn('NextToken', data)
         self.assertNotEmpty(data['Snapshots'])
 
+    @decorators.idempotent_id('fef90b60-0a46-4802-a822-98ccb58ff18c')
     def test_snapshots_paging(self):
         count = 0
         max_results = 5
@@ -276,6 +305,7 @@ class SnapshotPagingTest(scenario_base.BaseScenarioTest):
 
         self.assertEqual(self.SNAPSHOTS_COUNT, count)
 
+    @decorators.idempotent_id('8379d875-2979-4573-858f-2fd331ae992c')
     def test_invalid_paging(self):
         self.assertRaises('InvalidParameterValue',
             self.client.describe_snapshots, MaxResults=4)
@@ -294,6 +324,8 @@ class InstancePagingTest(scenario_base.BaseScenarioTest):
     @base.safe_setup
     def setUpClass(cls):
         super(InstancePagingTest, cls).setUpClass()
+        if 'amazon' in CONF.aws.ec2_url:
+            raise cls.skipException('Paging is broken in Amazon.')
         if not CONF.aws.image_id:
             raise cls.skipException('aws image_id does not provided')
 
@@ -318,6 +350,7 @@ class InstancePagingTest(scenario_base.BaseScenarioTest):
             cls.get_instance_waiter().wait_available(instance_id,
                                                      final_set=('running'))
 
+    @decorators.idempotent_id('703da498-c73f-4fd1-a2be-2feddb5292d0')
     def test_simple_instances_paging_with_many_results(self):
         data = self.client.describe_instances(MaxResults=500)
         self.assertNotIn('NextToken', data)
@@ -332,14 +365,15 @@ class InstancePagingTest(scenario_base.BaseScenarioTest):
         self._collect_own_instances(data, instances)
         self.assertEqual(count, len(instances))
 
+    @decorators.idempotent_id('f494a2a8-6d75-4ef4-ae15-ac4fd1269107')
     def test_simple_instances_paging_with_min_results(self):
         max_results = 5
         data = self.client.describe_instances(MaxResults=max_results)
         self.assertIn('NextToken', data)
         self.assertEqual(max_results, self._count_instances(data))
 
+    @decorators.idempotent_id('429802be-d599-4732-a310-3ffe8274df54')
     def test_instances_paging(self):
-        real_count = 0
         max_results = 5
         kwargs = {'MaxResults': max_results}
         instances = set()
@@ -354,6 +388,7 @@ class InstancePagingTest(scenario_base.BaseScenarioTest):
         count = self.RESERVATIONS_COUNT * self.INSTANCES_IN_RESERVATIONS_COUNT
         self.assertEqual(count, len(instances))
 
+    @decorators.idempotent_id('061d564d-6d3a-44a8-bec9-9dba04f6f362')
     def test_invalid_paging(self):
         self.assertRaises('InvalidParameterValue',
             self.client.describe_instances, MaxResults=4)
