@@ -53,11 +53,14 @@ TIME_ATTACH_NETWORK_INTERFACE = timeutils.isotime(None, True)
 MAC_ADDRESS = 'fb:10:2e:b2:ba:b7'
 
 # vpc constants
+ID_EC2_VPC_DEFAULT = random_ec2_id('vpc')
 ID_EC2_VPC_1 = random_ec2_id('vpc')
 ID_EC2_VPC_2 = random_ec2_id('vpc')
+ID_OS_ROUTER_DEFAULT = random_os_id()
 ID_OS_ROUTER_1 = random_os_id()
 ID_OS_ROUTER_2 = random_os_id()
 
+CIDR_VPC_DEFAULT = '172.31.0.0/16'
 CIDR_VPC_1 = '10.10.0.0/16'
 CIDR_VPC_2 = '10.20.0.0/16'
 ID_OS_PUBLIC_NETWORK = random_os_id()
@@ -67,21 +70,27 @@ IP_ROUTER_1_EXTERNAL_V6 = '::ffff:172.20.12.25'
 
 
 # internet gateway constants
+ID_EC2_IGW_DEFAULT = random_ec2_id('igw')
 ID_EC2_IGW_1 = random_ec2_id('igw')
 ID_EC2_IGW_2 = random_ec2_id('igw')
 
 
 # subnet constants
+ID_EC2_SUBNET_DEFAULT = random_ec2_id('subnet')
 ID_EC2_SUBNET_1 = random_ec2_id('subnet')
 ID_EC2_SUBNET_2 = random_ec2_id('subnet')
+ID_OS_SUBNET_DEFAULT = random_os_id()
 ID_OS_SUBNET_1 = random_os_id()
 ID_OS_SUBNET_2 = random_os_id()
+ID_OS_NETWORK_DEFAULT = random_os_id()
 ID_OS_NETWORK_1 = random_os_id()
 ID_OS_NETWORK_2 = random_os_id()
 
+CIDR_SUBNET_DEFAULT = '172.31.0.0/20'
 CIDR_SUBNET_1 = '10.10.1.0/24'
 IP_FIRST_SUBNET_1 = '10.10.1.4'
 IP_LAST_SUBNET_1 = '10.10.1.254'
+IP_GATEWAY_SUBNET_DEFAULT = '172.31.0.1'
 IP_GATEWAY_SUBNET_1 = '10.10.1.1'
 IP_GATEWAY_SUBNET_2 = '10.10.2.1'
 CIDR_SUBNET_2 = '10.10.2.0/24'
@@ -90,13 +99,16 @@ IP_LAST_SUBNET_2 = '10.10.2.254'
 
 
 # network interface constants
+ID_EC2_NETWORK_INTERFACE_DEFAULT = random_ec2_id('eni')
 ID_EC2_NETWORK_INTERFACE_1 = random_ec2_id('eni')
 ID_EC2_NETWORK_INTERFACE_2 = random_ec2_id('eni')
 ID_EC2_NETWORK_INTERFACE_2_ATTACH = (
     ID_EC2_NETWORK_INTERFACE_2.replace('eni', 'eni-attach'))
+ID_OS_PORT_DEFAULT = random_os_id()
 ID_OS_PORT_1 = random_os_id()
 ID_OS_PORT_2 = random_os_id()
 
+IP_NETWORK_INTERFACE_DEFAULT = '172.31.0.4'
 IP_NETWORK_INTERFACE_1 = '10.10.1.4'
 IP_NETWORK_INTERFACE_2 = '10.10.2.254'
 IP_NETWORK_INTERFACE_2_EXT_1 = '10.10.2.4'
@@ -104,15 +116,19 @@ IP_NETWORK_INTERFACE_2_EXT_2 = '10.10.2.5'
 IPS_NETWORK_INTERFACE_2 = (IP_NETWORK_INTERFACE_2,
                            IP_NETWORK_INTERFACE_2_EXT_1,
                            IP_NETWORK_INTERFACE_2_EXT_2)
+DESCRIPTION_NETWORK_INTERFACE_DEFAULT = 'descriptionDefault'
 DESCRIPTION_NETWORK_INTERFACE_1 = 'description1'
 DESCRIPTION_NETWORK_INTERFACE_2 = 'description2'
 
 
 # instance constants
+ID_EC2_INSTANCE_DEFAULT = random_ec2_id('i')
 ID_EC2_INSTANCE_1 = random_ec2_id('i')
 ID_EC2_INSTANCE_2 = random_ec2_id('i')
+ID_OS_INSTANCE_DEFAULT = random_os_id()
 ID_OS_INSTANCE_1 = random_os_id()
 ID_OS_INSTANCE_2 = random_os_id()
+ID_EC2_RESERVATION_DEFAULT = random_ec2_id('r')
 ID_EC2_RESERVATION_1 = random_ec2_id('r')
 ID_EC2_RESERVATION_2 = random_ec2_id('r')
 
@@ -129,8 +145,11 @@ ID_EC2_DHCP_OPTIONS_2 = random_ec2_id('dopt')
 
 
 # address constants
+ID_EC2_ADDRESS_DEFAULT = random_ec2_id('eipalloc')
 ID_EC2_ADDRESS_1 = random_ec2_id('eipalloc')
 ID_EC2_ADDRESS_2 = random_ec2_id('eipalloc')
+ID_EC2_ASSOCIATION_DEFAULT = ID_EC2_ADDRESS_DEFAULT.replace('eipalloc',
+                                                            'eipassoc')
 ID_EC2_ASSOCIATION_1 = ID_EC2_ADDRESS_1.replace('eipalloc', 'eipassoc')
 ID_EC2_ASSOCIATION_2 = ID_EC2_ADDRESS_2.replace('eipalloc', 'eipassoc')
 ID_OS_FLOATING_IP_1 = random_os_id()
@@ -142,12 +161,19 @@ IP_ADDRESS_NOVA_1 = '192.168.2.100'
 
 
 # security group constants
+ID_EC2_SECURITY_GROUP_DEFAULT = random_ec2_id('sg')
 ID_EC2_SECURITY_GROUP_1 = random_ec2_id('sg')
 ID_EC2_SECURITY_GROUP_2 = random_ec2_id('sg')
 ID_EC2_SECURITY_GROUP_3 = random_ec2_id('sg')
+ID_EC2_SECURITY_GROUP_4 = random_ec2_id('sg')
+ID_EC2_SECURITY_GROUP_5 = random_ec2_id('sg')
+ID_EC2_SECURITY_GROUP_6 = random_ec2_id('sg')
+ID_OS_SECURITY_GROUP_DEFAULT = random_os_id()
 ID_OS_SECURITY_GROUP_1 = random_os_id()
 ID_OS_SECURITY_GROUP_2 = random_os_id()
 ID_OS_SECURITY_GROUP_3 = random_os_id()
+ID_OS_SECURITY_GROUP_4 = random_os_id()
+ID_OS_SECURITY_GROUP_5 = random_os_id()
 
 ID_NOVA_OS_SECURITY_GROUP_1 = 1
 ID_NOVA_OS_SECURITY_GROUP_2 = 2
@@ -156,9 +182,12 @@ NAME_DEFAULT_OS_SECURITY_GROUP = 'default'
 
 
 # route table constants
+ID_EC2_ROUTE_TABLE_DEFAULT = random_ec2_id('rtb')
 ID_EC2_ROUTE_TABLE_1 = random_ec2_id('rtb')
 ID_EC2_ROUTE_TABLE_2 = random_ec2_id('rtb')
 ID_EC2_ROUTE_TABLE_3 = random_ec2_id('rtb')
+ID_EC2_ROUTE_TABLE_ASSOCIATION_DEFAULT = ID_EC2_VPC_DEFAULT.replace('vpc',
+                                                                    'rtbassoc')
 ID_EC2_ROUTE_TABLE_ASSOCIATION_1 = ID_EC2_VPC_1.replace('vpc', 'rtbassoc')
 ID_EC2_ROUTE_TABLE_ASSOCIATION_2 = ID_EC2_SUBNET_2.replace('subnet',
                                                            'rtbassoc')
@@ -377,16 +406,29 @@ CUSTOMER_GATEWAY_CONFIGURATION_2 = etree.tostring(
 
 # vpc objects
 # 2 vpcs in normal state
+DB_VPC_DEFAULT = {'id': ID_EC2_VPC_DEFAULT,
+                  'os_id': ID_OS_ROUTER_DEFAULT,
+                  'vpc_id': None,
+                  'is_default': True,
+                  'cidr_block': CIDR_VPC_DEFAULT,
+                  'route_table_id': ID_EC2_ROUTE_TABLE_DEFAULT}
 DB_VPC_1 = {'id': ID_EC2_VPC_1,
             'os_id': ID_OS_ROUTER_1,
             'vpc_id': None,
+            'is_default': False,
             'cidr_block': CIDR_VPC_1,
             'route_table_id': ID_EC2_ROUTE_TABLE_1}
 DB_VPC_2 = {'id': ID_EC2_VPC_2,
             'os_id': ID_OS_ROUTER_2,
             'vpc_id': None,
+            # is_default is false by default, omit it to check this
             'cidr_block': CIDR_VPC_2}
 
+EC2_VPC_DEFAULT = {'vpcId': ID_EC2_VPC_DEFAULT,
+                   'cidrBlock': CIDR_VPC_DEFAULT,
+                   'isDefault': True,
+                   'state': 'available',
+                   'dhcpOptionsId': 'default'}
 EC2_VPC_1 = {'vpcId': ID_EC2_VPC_1,
              'cidrBlock': CIDR_VPC_1,
              'isDefault': False,
@@ -398,6 +440,9 @@ EC2_VPC_2 = {'vpcId': ID_EC2_VPC_2,
              'state': 'available',
              'dhcpOptionsId': 'default'}
 
+OS_ROUTER_DEFAULT = {'id': ID_OS_ROUTER_DEFAULT,
+                     'name': ID_EC2_VPC_DEFAULT,
+                     'external_gateway_info': None}
 OS_ROUTER_1 = {'id': ID_OS_ROUTER_1,
                'name': ID_EC2_VPC_1,
                'external_gateway_info': {
@@ -411,6 +456,9 @@ OS_ROUTER_2 = {'id': ID_OS_ROUTER_2,
 
 # internet gateway objects
 # 2 internate gateway, the first is attached to the first vpc
+DB_IGW_DEFAULT = {'id': ID_EC2_IGW_DEFAULT,
+                  'os_id': None,
+                  'vpc_id': ID_EC2_VPC_DEFAULT}
 DB_IGW_1 = {'id': ID_EC2_IGW_1,
             'os_id': None,
             'vpc_id': ID_EC2_VPC_1}
@@ -418,6 +466,9 @@ DB_IGW_2 = {'id': ID_EC2_IGW_2,
             'os_id': None,
             'vpc_id': None}
 
+EC2_IGW_DEFAULT = {'internetGatewayId': ID_EC2_IGW_DEFAULT,
+                   'attachmentSet': [{'vpcId': ID_EC2_VPC_DEFAULT,
+                                      'state': 'available'}]}
 EC2_IGW_1 = {'internetGatewayId': ID_EC2_IGW_1,
              'attachmentSet': [{'vpcId': ID_EC2_VPC_1,
                                 'state': 'available'}]}
@@ -427,6 +478,9 @@ EC2_IGW_2 = {'internetGatewayId': ID_EC2_IGW_2,
 
 # subnet objects
 # 2 subnets in the first vpc
+DB_SUBNET_DEFAULT = {'id': ID_EC2_SUBNET_DEFAULT,
+                     'os_id': ID_OS_SUBNET_DEFAULT,
+                     'vpc_id': ID_EC2_VPC_DEFAULT}
 DB_SUBNET_1 = {'id': ID_EC2_SUBNET_1,
                'os_id': ID_OS_SUBNET_1,
                'vpc_id': ID_EC2_VPC_1,
@@ -437,6 +491,13 @@ DB_SUBNET_2 = {'id': ID_EC2_SUBNET_2,
                'route_table_id': ID_EC2_ROUTE_TABLE_3,
                'os_vpnservice_id': ID_OS_VPNSERVICE_2}
 
+EC2_SUBNET_DEFAULT = {'subnetId': ID_EC2_SUBNET_DEFAULT,
+                      'state': 'available',
+                      'vpcId': ID_EC2_VPC_DEFAULT,
+                      'cidrBlock': CIDR_SUBNET_DEFAULT,
+                      'defaultForAz': False,
+                      'availableIpAddressCount': 4093,
+                      'mapPublicIpOnLaunch': False}
 EC2_SUBNET_1 = {'subnetId': ID_EC2_SUBNET_1,
                 'state': 'available',
                 'vpcId': ID_EC2_VPC_1,
@@ -452,6 +513,16 @@ EC2_SUBNET_2 = {'subnetId': ID_EC2_SUBNET_2,
                 'availableIpAddressCount': 253,
                 'mapPublicIpOnLaunch': False}
 
+OS_SUBNET_DEFAULT = {'id': ID_OS_SUBNET_DEFAULT,
+                     'network_id': ID_OS_NETWORK_DEFAULT,
+                     'name': ID_EC2_SUBNET_DEFAULT,
+                     'ip_version': '4',
+                     'cidr': CIDR_SUBNET_DEFAULT,
+                     'host_routes': [{'nexthop': IP_GATEWAY_SUBNET_DEFAULT,
+                                      'destination': CIDR_VPC_DEFAULT},
+                                     {'nexthop': IP_GATEWAY_SUBNET_DEFAULT,
+                                      'destination': '0.0.0.0/0'}],
+                     'gateway_ip': None}
 OS_SUBNET_1 = {'id': ID_OS_SUBNET_1,
                'network_id': ID_OS_NETWORK_1,
                'name': ID_EC2_SUBNET_1,
@@ -469,6 +540,9 @@ OS_SUBNET_2 = {'id': ID_OS_SUBNET_2,
                'cidr': CIDR_SUBNET_2,
                'host_routes': [],
                'gateway_ip': None}
+OS_NETWORK_DEFAULT = {'id': ID_OS_NETWORK_DEFAULT,
+                      'name': ID_EC2_SUBNET_DEFAULT,
+                      'status': 'available'}
 OS_NETWORK_1 = {'id': ID_OS_NETWORK_1,
                 'name': ID_EC2_SUBNET_1,
                 'status': 'available'}
@@ -479,6 +553,14 @@ OS_NETWORK_2 = {'id': ID_OS_NETWORK_2,
 
 # network interface objects
 # 2 ports in both subnets, the second is attached to the first instance
+DB_NETWORK_INTERFACE_DEFAULT = {'id': ID_EC2_NETWORK_INTERFACE_DEFAULT,
+                                'os_id': ID_OS_PORT_DEFAULT,
+                                'vpc_id': ID_EC2_VPC_DEFAULT,
+                                'subnet_id': ID_EC2_SUBNET_DEFAULT,
+                                'description': (
+                                    DESCRIPTION_NETWORK_INTERFACE_DEFAULT),
+                                'private_ip_address': (
+                                    IP_NETWORK_INTERFACE_DEFAULT)}
 DB_NETWORK_INTERFACE_1 = {'id': ID_EC2_NETWORK_INTERFACE_1,
                           'os_id': ID_OS_PORT_1,
                           'vpc_id': ID_EC2_VPC_1,
@@ -496,6 +578,24 @@ DB_NETWORK_INTERFACE_2 = {'id': ID_EC2_NETWORK_INTERFACE_2,
                           'delete_on_termination': False,
                           'attach_time': TIME_ATTACH_NETWORK_INTERFACE}
 
+EC2_NETWORK_INTERFACE_DEFAULT = {
+    'networkInterfaceId': ID_EC2_NETWORK_INTERFACE_DEFAULT,
+    'status': 'available',
+    'vpcId': ID_EC2_VPC_DEFAULT,
+    'subnetId': ID_EC2_SUBNET_DEFAULT,
+    'description': DESCRIPTION_NETWORK_INTERFACE_DEFAULT,
+    'macAddress': MAC_ADDRESS,
+    'privateIpAddress': IP_NETWORK_INTERFACE_DEFAULT,
+    'privateIpAddressesSet': [
+        {'privateIpAddress': IP_NETWORK_INTERFACE_DEFAULT,
+         'primary': True}],
+    'sourceDestCheck': True,
+    'ownerId': ID_OS_PROJECT,
+    'requesterManaged': False,
+    'groupSet': [{'groupName': NAME_DEFAULT_OS_SECURITY_GROUP,
+                  'groupId': ID_EC2_SECURITY_GROUP_DEFAULT}],
+    'tagSet': [],
+}
 EC2_NETWORK_INTERFACE_1 = {
     'networkInterfaceId': ID_EC2_NETWORK_INTERFACE_1,
     'status': 'available',
@@ -591,6 +691,13 @@ OS_PORT_2 = {'id': ID_OS_PORT_2,
 TIME_CREATE_INSTANCE_1 = timeutils.isotime(None, True)
 TIME_CREATE_INSTANCE_2 = timeutils.isotime(None, True)
 
+DB_INSTANCE_DEFAULT = {
+    'id': ID_EC2_INSTANCE_DEFAULT,
+    'os_id': ID_OS_INSTANCE_DEFAULT,
+    'vpc_id': ID_EC2_VPC_DEFAULT,
+    'reservation_id': ID_EC2_RESERVATION_DEFAULT,
+    'launch_index': 0,
+}
 DB_INSTANCE_1 = {
     'id': ID_EC2_INSTANCE_1,
     'os_id': ID_OS_INSTANCE_1,
@@ -607,6 +714,68 @@ DB_INSTANCE_2 = {
     'client_token': CLIENT_TOKEN_INSTANCE_2,
 }
 
+EC2_INSTANCE_DEFAULT = {
+    'instanceId': ID_EC2_INSTANCE_DEFAULT,
+    'privateIpAddress': IP_NETWORK_INTERFACE_2,
+    'vpcId': ID_EC2_VPC_DEFAULT,
+    'subnetId': ID_EC2_SUBNET_DEFAULT,
+    'groupSet': [{'groupName': NAME_DEFAULT_OS_SECURITY_GROUP,
+                  'groupId': ID_EC2_SECURITY_GROUP_1}],
+    'networkInterfaceSet': [
+        {'networkInterfaceId': ID_EC2_NETWORK_INTERFACE_2,
+         'status': 'in-use',
+         'vpcId': ID_EC2_VPC_DEFAULT,
+         'subnetId': ID_EC2_SUBNET_DEFAULT,
+         'description': DESCRIPTION_NETWORK_INTERFACE_2,
+         'macAddress': MAC_ADDRESS,
+         'privateIpAddress': IP_NETWORK_INTERFACE_2,
+         'association': {
+             'ipOwnerId': ID_OS_PROJECT,
+             'publicDnsName': None,
+             'publicIp': IP_ADDRESS_2,
+         },
+         'privateIpAddressesSet': [
+             {'privateIpAddress': IP_NETWORK_INTERFACE_2,
+              'primary': True,
+              'association': {
+                  'ipOwnerId': ID_OS_PROJECT,
+                  'publicDnsName': None,
+                  'publicIp': IP_ADDRESS_2}},
+             {'privateIpAddress': IP_NETWORK_INTERFACE_2_EXT_1,
+              'primary': False},
+             {'privateIpAddress': IP_NETWORK_INTERFACE_2_EXT_2,
+              'primary': False},
+         ],
+         'attachment': {
+             'status': 'attached',
+             'deviceIndex': 0,
+             'attachTime': TIME_ATTACH_NETWORK_INTERFACE,
+             'deleteOnTermination': False,
+             'attachmentId': ID_EC2_NETWORK_INTERFACE_2_ATTACH,
+         },
+         'sourceDestCheck': True,
+         'ownerId': ID_OS_PROJECT,
+         'requesterManaged': False,
+         'groupSet': [{'groupName': NAME_DEFAULT_OS_SECURITY_GROUP,
+                       'groupId': ID_EC2_SECURITY_GROUP_1}]},
+    ],
+    'amiLaunchIndex': 0,
+    'placement': {'availabilityZone': None},
+    'dnsName': None,
+    'instanceState': {'code': 0, 'name': 'pending'},
+    'imageId': ID_EC2_IMAGE_1,
+    'kernelId': ID_EC2_IMAGE_AKI_1,
+    'ramdiskId': ID_EC2_IMAGE_ARI_1,
+    'productCodesSet': [],
+    'privateDnsName': '%s-%s' % (ID_EC2_RESERVATION_DEFAULT, 0),
+    'keyName': NAME_KEY_PAIR,
+    'launchTime': TIME_CREATE_INSTANCE_1,
+    'rootDeviceType': 'instance-store',
+    'instanceType': 'fake_flavor',
+    'ipAddress': IP_ADDRESS_2,
+    'rootDeviceName': ROOT_DEVICE_NAME_INSTANCE_1,
+    'sourceDestCheck': True,
+}
 EC2_INSTANCE_1 = {
     'instanceId': ID_EC2_INSTANCE_1,
     'privateIpAddress': IP_NETWORK_INTERFACE_2,
@@ -695,6 +864,12 @@ EC2_INSTANCE_2 = {
     'rootDeviceName': ROOT_DEVICE_NAME_INSTANCE_2,
     'clientToken': CLIENT_TOKEN_INSTANCE_2,
 }
+EC2_RESERVATION_DEFAULT = {
+    'reservationId': ID_EC2_RESERVATION_DEFAULT,
+    'ownerId': ID_OS_PROJECT,
+    'instancesSet': [EC2_INSTANCE_DEFAULT],
+    'groupSet': [],
+}
 EC2_RESERVATION_1 = {
     'reservationId': ID_EC2_RESERVATION_1,
     'ownerId': ID_OS_PROJECT,
@@ -863,14 +1038,14 @@ OS_DHCP_OPTIONS_1 = {'extra_dhcp_opts': [{'opt_name': 'domain-name',
 
 # address objects
 
-class NovaFloatingIp(object):
-
-    def __init__(self, nova_ip_dict):
-        self.id = nova_ip_dict['id']
-        self.ip = nova_ip_dict['ip']
-        self.fixed_ip = nova_ip_dict['fixed_ip']
-        self.instance_id = nova_ip_dict['instance_id']
-
+DB_ADDRESS_DEFAULT = {
+    'id': ID_EC2_ADDRESS_DEFAULT,
+    'os_id': ID_OS_FLOATING_IP_2,
+    'vpc_id': None,
+    'public_ip': IP_ADDRESS_2,
+    'network_interface_id': ID_EC2_NETWORK_INTERFACE_DEFAULT,
+    'private_ip_address': IP_NETWORK_INTERFACE_DEFAULT,
+}
 DB_ADDRESS_1 = {
     'id': ID_EC2_ADDRESS_1,
     'os_id': ID_OS_FLOATING_IP_1,
@@ -911,6 +1086,16 @@ EC2_ADDRESS_2 = {
     'privateIpAddress': IP_NETWORK_INTERFACE_2,
     'networkInterfaceOwnerId': ID_OS_PROJECT,
 }
+EC2_ADDRESS_DEFAULT = {
+    'allocationId': ID_EC2_ADDRESS_DEFAULT,
+    'publicIp': IP_ADDRESS_2,
+    'domain': 'vpc',
+    'instanceId': ID_EC2_INSTANCE_DEFAULT,
+    'associationId': ID_EC2_ASSOCIATION_DEFAULT,
+    'networkInterfaceId': ID_EC2_NETWORK_INTERFACE_DEFAULT,
+    'privateIpAddress': IP_NETWORK_INTERFACE_DEFAULT,
+    'networkInterfaceOwnerId': ID_OS_PROJECT,
+}
 
 OS_FLOATING_IP_1 = {
     'id': ID_OS_FLOATING_IP_1,
@@ -925,31 +1110,14 @@ OS_FLOATING_IP_2 = {
     'fixed_ip_address': IP_NETWORK_INTERFACE_2,
 }
 
-NOVA_FLOATING_IP_1 = {
-    'id': ID_OS_FLOATING_IP_1,
-    'ip': IP_ADDRESS_1,
-    'instance_id': None,
-    'fixed_ip': None,
-}
-NOVA_FLOATING_IP_2 = {
-    'id': ID_OS_FLOATING_IP_2,
-    'ip': IP_ADDRESS_2,
-    'instance_id': ID_OS_INSTANCE_1,
-    'fixed_ip': IP_NETWORK_INTERFACE_2,
-}
-
 
 # security group objects
 
-class NovaSecurityGroup(object):
-
-    def __init__(self, nova_group_dict):
-        self.id = nova_group_dict['id']
-        self.name = nova_group_dict['name']
-        self.description = nova_group_dict['description']
-        self.tenant_id = ID_OS_PROJECT
-        self.rules = nova_group_dict['security_group_rules']
-
+DB_SECURITY_GROUP_DEFAULT = {
+    'id': ID_EC2_SECURITY_GROUP_DEFAULT,
+    'os_id': ID_OS_SECURITY_GROUP_DEFAULT,
+    'vpc_id': ID_EC2_VPC_DEFAULT,
+}
 DB_SECURITY_GROUP_1 = {
     'id': ID_EC2_SECURITY_GROUP_1,
     'os_id': ID_OS_SECURITY_GROUP_1,
@@ -965,6 +1133,21 @@ DB_SECURITY_GROUP_3 = {
     'os_id': ID_OS_SECURITY_GROUP_3,
     'vpc_id': None,
 }
+DB_SECURITY_GROUP_4 = {
+    'id': ID_EC2_SECURITY_GROUP_4,
+    'os_id': ID_OS_SECURITY_GROUP_4,
+    'vpc_id': None,
+}
+DB_SECURITY_GROUP_5 = {
+    'id': ID_EC2_SECURITY_GROUP_5,
+    'os_id': ID_OS_SECURITY_GROUP_5,
+    'vpc_id': ID_EC2_VPC_DEFAULT,
+}
+DB_SECURITY_GROUP_6 = {
+    'id': ID_EC2_SECURITY_GROUP_6,
+    'os_id': None,
+    'vpc_id': None,
+}
 OS_SECURITY_GROUP_RULE_1 = {
     'direction': 'ingress',
     'ethertype': 'IPv4',
@@ -987,6 +1170,22 @@ OS_SECURITY_GROUP_RULE_2 = {
     'remote_ip_prefix': None,
     'security_group_id': ID_OS_SECURITY_GROUP_2
 }
+OS_SECURITY_GROUP_DEFAULT = {
+    'id': ID_OS_SECURITY_GROUP_DEFAULT,
+    'name': ID_EC2_VPC_DEFAULT,
+    'security_group_rules':
+    [{'remote_group_id': None,
+      'direction': 'egress',
+      'remote_ip_prefix': None,
+      'protocol': None,
+      'port_range_max': None,
+      'security_group_id': ID_OS_SECURITY_GROUP_DEFAULT,
+      'port_range_min': None,
+      'ethertype': 'IPv4',
+      'id': random_os_id()}],
+    'description': 'Group description',
+    'tenant_id': ID_OS_PROJECT
+}
 OS_SECURITY_GROUP_1 = {
     'id': ID_OS_SECURITY_GROUP_1,
     'name': ID_EC2_VPC_1,
@@ -1028,6 +1227,61 @@ OS_SECURITY_GROUP_3 = {
     'description': 'Group description',
     'tenant_id': ID_OS_PROJECT
 }
+OS_SECURITY_GROUP_4 = {
+    'id': ID_OS_SECURITY_GROUP_4,
+    'name': 'groupname2',
+    'security_group_rules': [
+        {'direction': 'ingress',
+         'ethertype': 'IPv4',
+         'id': random_os_id(),
+         'port_range_min': 10,
+         'port_range_max': 10,
+         'protocol': 'tcp',
+         'remote_group_id': None,
+         'remote_ip_prefix': '192.168.1.0/24',
+         'security_group_id': ID_OS_SECURITY_GROUP_4},
+        {'direction': 'egress',
+         'ethertype': 'IPv4',
+         'id': random_os_id(),
+         'port_range_min': 10,
+         'port_range_max': None,
+         'protocol': 100,
+         'remote_group_id': ID_OS_SECURITY_GROUP_1,
+         'remote_ip_prefix': None,
+         'security_group_id': ID_OS_SECURITY_GROUP_4}
+    ],
+    'description': 'Group description',
+    'tenant_id': ID_OS_PROJECT
+}
+OS_SECURITY_GROUP_5 = {
+    'id': ID_OS_SECURITY_GROUP_5,
+    'name': 'groupname2',
+    'security_group_rules': [
+        {'remote_group_id': None,
+         'direction': 'egress',
+         'remote_ip_prefix': None,
+         'protocol': None,
+         'port_range_max': None,
+         'security_group_id': ID_OS_SECURITY_GROUP_5,
+         'port_range_min': None,
+         'ethertype': 'IPv4',
+         'id': random_os_id()}
+    ],
+    'description': 'Group description',
+    'tenant_id': ID_OS_PROJECT
+}
+EC2_SECURITY_GROUP_DEFAULT = {
+    'vpcId': ID_EC2_VPC_DEFAULT,
+    'groupDescription': 'Group description',
+    'ipPermissions': None,
+    'groupName': NAME_DEFAULT_OS_SECURITY_GROUP,
+    'ipPermissionsEgress':
+    [{'toPort': -1,
+      'ipProtocol': -1,
+      'fromPort': -1}],
+    'ownerId': ID_OS_PROJECT,
+    'groupId': ID_EC2_SECURITY_GROUP_DEFAULT
+}
 EC2_SECURITY_GROUP_1 = {
     'vpcId': ID_EC2_VPC_1,
     'groupDescription': 'Group description',
@@ -1071,6 +1325,40 @@ EC2_SECURITY_GROUP_3 = {
     'ownerId': ID_OS_PROJECT,
     'groupId': ID_EC2_SECURITY_GROUP_3
 }
+EC2_SECURITY_GROUP_4 = {
+    'groupDescription': 'Group description',
+    'ipPermissions':
+    [{'toPort': 10,
+      'ipProtocol': 'tcp',
+      'fromPort': 10,
+      'ipRanges':
+      [{'cidrIp': '192.168.1.0/24'}]
+      }],
+    'groupName': 'groupname2',
+    'ipPermissionsEgress':
+    [{'toPort': -1,
+      'ipProtocol': 100,
+      'fromPort': 10,
+      'groups':
+      [{'groupId': ID_EC2_SECURITY_GROUP_1,
+        'groupName': NAME_DEFAULT_OS_SECURITY_GROUP,
+        'userId': ID_OS_PROJECT}]
+      }],
+    'ownerId': ID_OS_PROJECT,
+    'groupId': ID_EC2_SECURITY_GROUP_4
+}
+EC2_SECURITY_GROUP_5 = {
+    'vpcId': ID_EC2_VPC_DEFAULT,
+    'groupDescription': 'Group description',
+    'ipPermissions': None,
+    'ipPermissionsEgress':
+    [{'toPort': -1,
+      'ipProtocol': -1,
+      'fromPort': -1}],
+    'groupName': 'groupname2',
+    'ownerId': ID_OS_PROJECT,
+    'groupId': ID_EC2_SECURITY_GROUP_5
+}
 
 NOVA_DB_SECURITY_GROUP_1 = {
     'id': ID_EC2_SECURITY_GROUP_1,
@@ -1159,6 +1447,15 @@ EC2_NOVA_SECURITY_GROUP_2 = {
 
 
 # route table objects
+DB_ROUTE_TABLE_DEFAULT = {
+    'id': ID_EC2_ROUTE_TABLE_DEFAULT,
+    'vpc_id': ID_EC2_VPC_DEFAULT,
+    'routes': [{'destination_cidr_block': CIDR_VPC_DEFAULT,
+                'gateway_id': None},
+               {'destination_cidr_block': '0.0.0.0/0',
+                'gateway_id': ID_EC2_IGW_DEFAULT}],
+}
+
 DB_ROUTE_TABLE_1 = {
     'id': ID_EC2_ROUTE_TABLE_1,
     'vpc_id': ID_EC2_VPC_1,
@@ -1184,6 +1481,25 @@ DB_ROUTE_TABLE_3 = {
                {'destination_cidr_block': CIDR_VPN_1_STATIC,
                 'gateway_id': ID_EC2_VPN_GATEWAY_1}],
 }
+EC2_ROUTE_TABLE_DEFAULT = {
+    'routeTableId': ID_EC2_ROUTE_TABLE_DEFAULT,
+    'vpcId': ID_EC2_VPC_DEFAULT,
+    'routeSet': [
+        {'destinationCidrBlock': CIDR_VPC_DEFAULT,
+         'gatewayId': 'local',
+         'state': 'active',
+         'origin': 'CreateRouteTable'},
+        {'destinationCidrBlock': '0.0.0.0/0',
+         'gatewayId': ID_EC2_IGW_DEFAULT,
+         'state': 'active',
+         'origin': 'CreateRoute'}],
+    'associationSet': [
+        {'routeTableAssociationId': ID_EC2_ROUTE_TABLE_ASSOCIATION_DEFAULT,
+         'routeTableId': ID_EC2_ROUTE_TABLE_DEFAULT,
+         'main': True}],
+    'propagatingVgwSet': [],
+    'tagSet': [],
+}
 EC2_ROUTE_TABLE_1 = {
     'routeTableId': ID_EC2_ROUTE_TABLE_1,
     'vpcId': ID_EC2_VPC_1,
