@@ -955,7 +955,7 @@ class RouteTableTestCase(base.ApiTestCase):
                              'nexthop': '127.0.0.1'},
                             {'destination': '169.254.169.254/32',
                              'nexthop': fakes.IP_GATEWAY_SUBNET_1}]))
-        self.assertEqual(None, gateway_ip)
+        self.assertIsNone(gateway_ip)
 
         host_routes, gateway_ip = (
             route_table_api._get_subnet_host_routes_and_gateway_ip(
@@ -1129,6 +1129,22 @@ class RouteTableTestCase(base.ApiTestCase):
             mock.ANY, self.neutron, 'fake_cleaner', fakes.DB_ROUTE_TABLE_1,
             [fakes.DB_SUBNET_1])
 
+    @mock.patch('ec2api.api.ec2utils.check_and_create_default_vpc')
+    def test_describe_route_tables_no_default_vpc(self, check_and_create):
+        self.configure(disable_ec2_classic=True)
+
+        def mock_check_and_create(context):
+            self.set_mock_db_items(fakes.DB_VPC_DEFAULT,
+                                   fakes.DB_IGW_DEFAULT,
+                                   fakes.DB_ROUTE_TABLE_DEFAULT)
+        check_and_create.side_effect = mock_check_and_create
+
+        resp = self.execute('DescribeRouteTables', {})
+        self.assertEqual(resp['routeTableSet'],
+                         [fakes.EC2_ROUTE_TABLE_DEFAULT])
+
+        check_and_create.assert_called_once_with(mock.ANY)
+
 
 class RouteTableValidatorTestCase(test_base.BaseTestCase):
 
