@@ -17,6 +17,8 @@ APIPASTE_FILE=$CONF_DIR/api-paste.ini
 
 AUTH_CACHE_DIR=${AUTH_CACHE_DIR:-/var/cache/ec2api}
 
+CACHE_BACKEND='oslo_cache.dict'
+
 #Check for environment
 if [[ -z "$OS_AUTH_URL" || -z "$OS_USERNAME" || -z "$OS_PASSWORD" ]]; then
     echo "Please set OS_AUTH_URL, OS_USERNAME, OS_PASSWORD"
@@ -217,8 +219,10 @@ function copynovaopt() {
 
 if [[ -n $(openstack catalog show network) ]]; then
     VPC_SUPPORT="True"
+    DISABLE_EC2_CLASSIC="True"
 else
     VPC_SUPPORT="False"
+    DISABLE_EC2_CLASSIC="False"
 fi
 if [[ "$VPC_SUPPORT" == "True" && -z "$EXTERNAL_NETWORK" ]]; then
     declare -a newtron_output
@@ -272,7 +276,7 @@ iniset $CONF_FILE DEFAULT log_dir "$LOG_DIR"
 iniset $CONF_FILE DEFAULT verbose True
 iniset $CONF_FILE DEFAULT keystone_ec2_tokens_url "$OS_AUTH_URL_WO_PATH/v3/ec2tokens"
 iniset $CONF_FILE database connection "$CONNECTION"
-iniset $CONF_FILE DEFAULT full_vpc_support "$VPC_SUPPORT"
+iniset $CONF_FILE DEFAULT disable_ec2_classic "$DISABLE_EC2_CLASSIC"
 iniset $CONF_FILE DEFAULT external_network "$EXTERNAL_NETWORK"
 
 GROUP_AUTHTOKEN="keystone_authtoken"
@@ -286,21 +290,33 @@ iniset $CONF_FILE $GROUP_AUTHTOKEN project_domain_name $SERVICE_DOMAIN_NAME
 iniset $CONF_FILE $GROUP_AUTHTOKEN user_domain_name $SERVICE_DOMAIN_NAME
 iniset $CONF_FILE $GROUP_AUTHTOKEN auth_type password
 
+GROUP_CACHE="cache"
+iniset $CONF_FILE $GROUP_CACHE enabled True
+iniset $CONF_FILE $GROUP_CACHE backend "$CACHE_BACKEND"
 
 if [[ -f "$NOVA_CONF" ]]; then
     # NOTE(ft): use swift instead internal s3 server if enabled
     if [[ -n $(openstack catalog show object-store 2>/dev/null) ]] &&
             [[ -n $(openstack catalog show s3 2>/dev/null) ]]; then
-        copynovaopt s3_host DEFAULT
-        copynovaopt s3_port DEFAULT
-        copynovaopt s3_affix_tenant DEFAULT
-        copynovaopt s3_use_ssl DEFAULT
+        s3_host="127.0.0.1"
+        if ini_has_option "$NOVA_CONF" DEFAULT "s3_host"; then
+            s3_host=$(iniget $NOVA_CONF DEFAULT $option_name)
+        fi
+        s3_port="3334"
+        if ini_has_option "$NOVA_CONF" DEFAULT "s3_port"; then
+            s3_port=$(iniget $NOVA_CONF DEFAULT $option_name)
+        fi
+        s3_proto="http"
+        if ini_has_option "$NOVA_CONF" DEFAULT "s3_use_ssl"; then
+            s3_use_ssl=$(iniget $NOVA_CONF DEFAULT $option_name)
+            s3_use_ssl=`echo $s3_use_ssl | awk '{print toupper($0)}'`
+            if [[ $s3_use_ssl == "TRUE" ]]; then
+                s3_proto="https"
+            fi
+        fi
+        iniset $CONF_FILE DEFAULT s3_url "$s3_proto://$s3_host:$s3_port"
+
     fi
-    copynovaopt cert_topic DEFAULT
-    copynovaopt rabbit_hosts oslo_messaging_rabbit
-    copynovaopt rabbit_password oslo_messaging_rabbit
-    copynovaopt rabbit_userid oslo_messaging_rabbit
-    # TODO(ft): it's necessary to support other available messaging implementations
 
     nova_state_path=$(iniget $NOVA_CONF DEFAULT state_path)
     root_state_path=$(dirname $nova_state_path)
